@@ -56,6 +56,7 @@ describe 'horizon' do
           "            'handlers': ['file'],",
           'SESSION_TIMEOUT = 3600',
           'TOKEN_TIMEOUT_MARGIN = 0',
+          'COMPRESS_ENABLED = True',
           'COMPRESS_OFFLINE = True',
           "FILE_UPLOAD_TEMP_DIR = '/tmp'",
         ])
@@ -67,6 +68,15 @@ describe 'horizon' do
         expect(content).not_to match(/^SESSION_ENGINE/)
       end
 
+      it { is_expected.to contain_file(platforms_params[:conf_d_dir]).with(
+        :ensure  => 'directory',
+        :mode    => '0755',
+        :purge   => false,
+        :recurse => false,
+        :owner   => platforms_params[:wsgi_user],
+        :group   => platforms_params[:wsgi_group],
+      ) }
+
       it 'creates a key file' do
         is_expected.to contain_file(platforms_params[:secret_key_file]).with(
           :mode      => '0600',
@@ -82,6 +92,7 @@ describe 'horizon' do
     context 'with overridden parameters' do
       before do
         params.merge!({
+          :purge_conf_d_dir                 => true,
           :cache_backend                    => 'django.core.cache.backends.memcached.MemcachedCache',
           :cache_timeout                    => 300,
           :cache_options                    => {'SOCKET_TIMEOUT' => 1,'SERVER_RETRIES' => 1,'DEAD_RETRY' => 1},
@@ -100,6 +111,7 @@ describe 'horizon' do
           :api_result_limit                 => 2000,
           :api_result_page_size             => 40,
           :dropdown_max_items               => 123,
+          :compress_enabled                 => false,
           :compress_offline                 => false,
           :hypervisor_options               => {'can_set_mount_point' => false, 'can_set_password' => true },
           :cinder_options                   => {'enable_backup' => true },
@@ -205,6 +217,7 @@ describe 'horizon' do
           "            'handlers': ['console', 'syslog'],",
           'SESSION_TIMEOUT = 1800',
           'TOKEN_TIMEOUT_MARGIN = 60',
+          'COMPRESS_ENABLED = False',
           'COMPRESS_OFFLINE = False',
           "FILE_UPLOAD_TEMP_DIR = '/var/spool/horizon'",
           'OVERVIEW_DAYS_RANGE = 1',
@@ -212,7 +225,14 @@ describe 'horizon' do
         ])
       end
 
-      it { is_expected.to contain_file(platforms_params[:conf_d_dir]).with_ensure('directory') }
+      it { is_expected.to contain_file(platforms_params[:conf_d_dir]).with(
+        :ensure  => 'directory',
+        :mode    => '0755',
+        :purge   => true,
+        :recurse => true,
+        :owner   => platforms_params[:wsgi_user],
+        :group   => platforms_params[:wsgi_group],
+      ) }
       it { is_expected.to_not contain_exec('refresh_horizon_django_compress') }
 
       it { is_expected.to contain_file(params[:file_upload_temp_dir]) }
@@ -661,6 +681,28 @@ describe 'horizon' do
       end
     end
 
+    context 'with totp enabled' do
+      before do
+        params.merge!({
+          :totp_enabled           => true,
+          :authentication_plugins => [
+            'openstack_auth.plugin.totp.TotpPlugin',
+            'openstack_auth.plugin.password.PasswordPlugin',
+            'openstack_auth.plugin.token.TokenPlugin'
+          ]
+        })
+      end
+      it 'configures totp options' do
+        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
+          'OPENSTACK_KEYSTONE_MFA_TOTP_ENABLED = True',
+          'AUTHENTICATION_PLUGINS = [',
+          "    'openstack_auth.plugin.totp.TotpPlugin',",
+          "    'openstack_auth.plugin.password.PasswordPlugin',",
+          "    'openstack_auth.plugin.token.TokenPlugin',",
+          ])
+      end
+    end
+
     context 'with help_url, bug_url and customization_module provided' do
       before do
         params.merge!({
